@@ -56,15 +56,8 @@ pageWithSidebar(
                                                    "Semicolon" = ";")),
                                     tooltip(refId = "sep", text = tags$img(src='file_sep.png', width='400px'), placement = "auto left"),
                                     hr(),
-                                    fluidRow(
-                                      column(width = 6,
-                                             actionButton(inputId = "refresh", label = "Refresh", icon = icon("refresh")),
-                                             tooltip(refId = "refresh", text = "Redraw the plot")
-                                      ),
-                                      column(width = 6,
-                                             actionButton(inputId = "exit", label = "Exit", class = "btn btn-danger")
-                                      )
-                                    )
+                                    actionButton(inputId = "refresh", label = "Refresh", icon = icon("refresh")),
+                                    tooltip(refId = "refresh", text = "Redraw the plot")
                            ),##EndOf::Tab_1
                            
                            # Tab 2: Statistical information
@@ -109,8 +102,8 @@ pageWithSidebar(
                                                                    #"75 % Quartile" = "q75", #not implemented yet
                                                                    "KDEmax"  = "kdemax",
                                                                    "Skewness" = "skewness",
-                                                                   "Kurtosis" = "kurtosis",
-                                                                   "Confidence interval" = "in.ci")),
+                                                                   "Kurtosis" = "kurtosis"
+                                                                   )),
                                     tooltip(refId = "stats", text = "Statistical parameters to be shown in the summary"),
                                     br(),
                                     div(align = "center", h5("Datapoint labels")),
